@@ -1,9 +1,9 @@
 package Mojolicious::Plugin::GoogleAnalytics;
+# ABSTRACT: GoogleAnalytics plugin
+$Mojolicious::Plugin::GoogleAnalytics::VERSION = '1.005';
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '1.004';
-
 has 'template' => 'analytics_template';
 
 sub register {
@@ -33,33 +33,17 @@ sub register {
 
 1;
 
-__DATA__
+=pod
 
-@@ analytics_template.html.ep
-
-%= javascript begin
-  var _gaq = _gaq || [];
-  _gaq.push(['_setAccount', '<%= $analytics_id %>']);
-  % if ($domain_sub) {
-  _gaq.push(['_setDomainName', <%= $domain_sub %>']);
-  % }
-  % if ($allow_multi_top_level) {
-  _gaq.push(['_setAllowLinker', true]);
-  % }
-  _gaq.push(['_trackPageview']);
-
-  (function() {
-    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
-    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
-    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
-  })();
-%= end
-
-__END__
+=encoding UTF-8
 
 =head1 NAME
 
-Mojolicious::Plugin::GoogleAnalytics - Mojolicious Plugin
+Mojolicious::Plugin::GoogleAnalytics - GoogleAnalytics plugin
+
+=head1 VERSION
+
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -73,16 +57,14 @@ Mojolicious::Plugin::GoogleAnalytics - Mojolicious Plugin
   <%= analytics_inc 'UA-32432-1', 'example.com', 1 %>
   </head> <!-- Make sure its just before closing head tag -->
 
-
 =head1 DESCRIPTION
 
-L<Mojolicious::Plugin::GoogleAnalytics> is a L<Mojolicious> plugin. Inserts Google Analytics code and associates your analytics id.
+L<Mojolicious::Plugin::GoogleAnalytics> is a L<Mojolicious>
+plugin. Inserts Google Analytics code and associates your analytics
+id.
 
 =head1 METHODS
 
-L<Mojolicious::Plugin::GoogleAnalytics> inherits all methods from
-L<Mojolicious::Plugin> and implements the following new ones.
-
 =head2 register
 
   $plugin->register(Mojolicious->new);
@@ -93,26 +75,70 @@ Register plugin in L<Mojolicious> application.
 
 =head2 Track Subdomains
 
-Put the domain which qualifies any subdomains you wish to track, eg. blog.example.com, apps.example.com will have the second arguement set to 'example.com'
+Put the domain which qualifies any subdomains you wish to track,
+eg. blog.example.com, apps.example.com will have the second arguement
+set to 'example.com'
 
 =head2 Multiple top level domains
 
-Default is set to 1 to allow domains such as example.fr, example.cn, and example.com
+Default is set to 1 to allow domains such as example.fr, example.cn,
+and example.com
 
 =head1 AUTHOR
 
-Adam Stokes E<lt>adamjs@cpan.orgE<gt>
+Adam Stokes <adamjs@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2013- Adam Stokes
+This software is copyright (c) 2014 by Adam Stokes.
 
-=head1 LICENSE
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
-Licensed under the same terms as Perl.
+=head1 DISCLAIMER OF WARRANTY
 
-=head1 SEE ALSO
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
 
-L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
 
 =cut
+
+__DATA__
+
+@@ analytics_template.html.ep
+
+%= javascript begin
+  var _gaq = _gaq || [];
+  _gaq.push(['_setAccount', '<%= $analytics_id %>']);
+  % if ($domain_sub) {
+  _gaq.push(['_setDomainName', '<%= $domain_sub %>']);
+  % }
+  % if ($allow_multi_top_level) {
+  _gaq.push(['_setAllowLinker', true]);
+  % }
+  _gaq.push(['_trackPageview']);
+
+  (function() {
+    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
+    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
+    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
+  })();
+%= end
+
